@@ -398,10 +398,13 @@ class RackspaceMonitoringDriver(MonitoringDriver):
 
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
-    def list_alarm_changelog(self, ex_next_marker=None):
+    def list_alarm_changelog(self, ex_next_marker=None, reverse=False):
         value_dict = {'url': '/changelogs/alarms',
                       'start_marker': ex_next_marker,
+                      'params': {},
                       'list_item_mapper': self._to_alarm_changelog}
+        if reverse:
+            value_dict['params']['reverse'] = reverse
 
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
@@ -679,11 +682,13 @@ class RackspaceMonitoringDriver(MonitoringDriver):
     def _to_audit(self, audit, value_dict):
         return audit
 
-    def list_audits(self, start_from=None, to=None):
+    def list_audits(self, start_from=None, to=None, reverse=False):
         # TODO: add start/end date support
         value_dict = {'url': '/audits',
                       'params': {'limit': 200},
                       'list_item_mapper': self._to_audit}
+        if reverse:
+            value_dict['params']['reverse'] = reverse
 
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
@@ -769,10 +774,15 @@ class RackspaceMonitoringDriver(MonitoringDriver):
         return resp
 
     def ex_list_alarm_notification_history(self, entity, alarm, check,
-                                           ex_next_marker=None):
-        value_dict = {'url': '/entities/%s/alarms/%s/notification_history/%s' %
-                              (entity.id, alarm.id, check.id),
-               'list_item_mapper': self._to_alarm_notification_history_obj}
+                                           ex_next_marker=None, reverse=False):
+        value_dict = {
+            'url': '/entities/%s/alarms/%s/notification_history/%s' %
+                   (entity.id, alarm.id, check.id),
+            'params': {},
+            'list_item_mapper': self._to_alarm_notification_history_obj}
+        if reverse:
+            value_dict['params']['reverse'] = reverse
+
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
     def _to_alarm_notification_history_obj(self, values, value_dict):
